from django.apps import AppConfig


class RestFrameworkTestConfig(AppConfig):
    name = "tests.rest_framework"
    label = "drf_test_app"
    verbose_name = "Rest Framework Test App"
